<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.4.0
 */

$mts_options = get_option( MTS_THEME_NAME );

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
get_header( 'shop' );

if ( is_shop() && ! is_paged() ) {
	if ( $mts_options['mts_shop_slider'] == '1' ) {
		?>
		<div class="banner clearfix shop-page-slider">
			<section class="slider">
				<div class="shop-slider-container clearfix loading">
					<div id="slider" class="shop-slider">
						<?php
						if ( ! empty( $mts_options['mts_custom_shop_slider'] ) ) {
							foreach ( $mts_options['mts_custom_shop_slider'] as $slide ) :
								?>
								<div>
									<div class="slides-shadow"></div>
									<?php echo wp_get_attachment_image( $slide['mts_custom_shop_slider_image'], 'magxp-slider', false, array('title' => '') ); ?>
									<div class="slide-caption">
										<h2 class="slide-title">
											<?php
											if ( ! empty( $slide['mts_custom_shop_slider_link'] ) ) :
												?>
												<a href="<?php echo esc_url( $slide['mts_custom_shop_slider_link'] ); ?>">
												<?php
											endif;
											echo esc_html( $slide['mts_custom_shop_slider_title'] );
											if ( ! empty( $slide['mts_custom_shop_slider_link'] ) ) : 
												?>
												</a>
												<?php
											endif;
											?>
										</h2>
										<p class="slide-text"><?php echo esc_html( $slide['mts_custom_shop_slider_text'] ); ?></p>
									</div>
								</div>
								<?php
							endforeach;
						}
						?>
					</div>
				</div>
			</section>
		</div><!-- slider-container -->
		<?php
	}
}

if ( is_shop() && ! is_paged() ) {
	// Features.
	if ( $mts_options['mts_shop_features'] == '1' && ! empty( $mts_options['mts_custom_shop_features'] ) ) {
		?>
		<div id="page">
			<section class="features">
				<?php
				foreach ( $mts_options['mts_custom_shop_features'] as $slide ) :
					// Remove size information.
					?>
					<div class="feature">
						<?php
						if ( ! empty( $slide['mts_custom_shop_feature_link'] ) ) {
							?>
							<a href="<?php echo $slide['mts_custom_shop_feature_link']; ?>">
							<?php
						}
						?>
						<div class="left">
							<i class="fa fa-<?php echo $slide['mts_custom_shop_feature_icon']; ?>"></i>
						</div>
						<div class="feature-content">
							<p class="featuretitle">
								<?php echo $slide['mts_custom_shop_feature_title']; ?>
							</p>
							<div class="feature-info"><?php echo $slide['mts_custom_shop_feature_text']; ?></div>
						</div>
						<?php
						if ( ! empty( $slide['mts_custom_shop_feature_link'] ) ) {
							?>
							</a>
							<?php
						}
						?>
					</div>
					<?php
				endforeach;
				?>
			</section>
		</div><!-- #page -->
		<?php
	}
}
?>
<div class="main-container">
	<div id="page" class="clearfix">
		<article class="<?php mts_article_class(); ?>">
			<div id="content_box" >
				<?php
				do_action( 'woocommerce_before_main_content' );
				if ( apply_filters( 'woocommerce_show_page_title', true ) ) :
					?>
					<h1 class="page-title"><?php woocommerce_page_title(); ?></h1>
					<?php
				endif;
				do_action( 'woocommerce_archive_description' );
				if ( have_posts() ) :
					do_action( 'woocommerce_before_shop_loop' );
					woocommerce_product_loop_start();
					woocommerce_product_subcategories();
					while ( have_posts() ) : the_post();
						wc_get_template_part( 'content', 'product' );
					endwhile; // end of the loop.
					woocommerce_product_loop_end();
					do_action( 'woocommerce_after_shop_loop' );
				elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) :
					wc_get_template( 'loop/no-products-found.php' );
				endif;
				do_action( 'woocommerce_after_main_content' );
				?>
			</div>
		</article>
		<?php get_sidebar(); ?>
	<?php get_footer(); ?>